@@ -13,17 +13,17 @@ else:
 class ControllerDataType(TypedDict, total=False):
     """Represent a controller data dict type."""
 
-    libraryVersion: str
+    sdkVersion: str
     type: int
     homeId: int
     ownNodeId: int
-    isSecondary: bool  # TODO: The following items are missing in the docs.
-    isUsingHomeIdFromOtherNetwork: bool
+    isPrimary: bool
+    isSUC: bool
+    nodeType: int
+    isUsingHomeIdFromOtherNetwork: bool  # TODO: The following items are missing in the docs.
     isSISPresent: bool
     wasRealPrimary: bool
-    isStaticUpdateController: bool
-    isSlave: bool
-    serialApiVersion: str
+    firmwareVersion: str
     manufacturerId: int
     productType: int
     productId: int
